about summary refs log tree commit diff
path: root/pkgs/development/haskell-modules/configuration-common.nix
diff options
context:
space:
mode:
authormaralorn <mail@maralorn.de>2023-10-22 12:37:39 +0200
committermaralorn <mail@maralorn.de>2023-10-22 12:37:39 +0200
commita1e8ef46c6e9657f48fbe5f0e0f738fb28fae65a (patch)
tree1fc94847c9028e9f482b0f1039cdae1792ba2097 /pkgs/development/haskell-modules/configuration-common.nix
parentb779210e3a07b5edaf0f8bc46f86477ea1c91da0 (diff)
haskellPackages: Eval fixes
Diffstat (limited to 'pkgs/development/haskell-modules/configuration-common.nix')
-rw-r--r--pkgs/development/haskell-modules/configuration-common.nix31
1 files changed, 13 insertions, 18 deletions
diff --git a/pkgs/development/haskell-modules/configuration-common.nix b/pkgs/development/haskell-modules/configuration-common.nix
index c2f5629198e9d..164a19ef623d9 100644
--- a/pkgs/development/haskell-modules/configuration-common.nix
+++ b/pkgs/development/haskell-modules/configuration-common.nix
@@ -57,15 +57,15 @@ self: super: {
           # not solvable short of recompiling GHC. Instead of adding
           # allowInconsistentDependencies for all reverse dependencies of hspec-core,
           # just upgrade to an hspec version without the offending dependency.
-          hspec-core = cself.hspec-core_2_11_5;
-          hspec-discover = cself.hspec-discover_2_11_5;
-          hspec = cself.hspec_2_11_5;
+          hspec-core = cself.hspec-core_2_11_6;
+          hspec-discover = cself.hspec-discover_2_11_6;
+          hspec = cself.hspec_2_11_6;
 
           # hspec-discover and hspec-core depend on hspec-meta for testing which
           # we need to avoid since it depends on ghc as well. Since hspec*_2_11*
           # are overridden to take the versioned attributes as inputs, we need
           # to make sure to override the versioned attribute with this fix.
-          hspec-discover_2_11_5 = dontCheck csuper.hspec-discover_2_11_5;
+          hspec-discover_2_11_6 = dontCheck csuper.hspec-discover_2_11_6;
 
           # Prevent dependency on doctest which causes an inconsistent dependency
           # due to depending on ghc which depends on directory etc.
@@ -194,11 +194,6 @@ self: super: {
     })
   ] super.aeson);
 
-  # aeson 2.2.0.0 requires th-abstraction >= 0.5 & < 0.6
-  aeson_2_2_0_0 = super.aeson_2_2_0_0.overrideScope (hfinal: hprev: {
-    th-abstraction = hfinal.th-abstraction_0_5_0_0;
-  });
-
   # 2023-06-28: Test error: https://hydra.nixos.org/build/225565149
   orbits = dontCheck super.orbits;
 
@@ -208,7 +203,7 @@ self: super: {
 
   # 2023-08-09: Jailbreak because of vector < 0.13
   monad-bayes = doJailbreak (super.monad-bayes.override {
-    hspec = self.hspec_2_11_5;
+    hspec = self.hspec_2_11_6;
   });
 
   # Disable tests failing on odd floating point numbers generated by QuickCheck 2.14.3
@@ -1679,19 +1674,19 @@ self: super: {
   servant-openapi3 = dontCheck super.servant-openapi3;
 
   # Give latest hspec correct dependency versions without overrideScope
-  hspec_2_11_5 = doDistribute (super.hspec_2_11_5.override {
-    hspec-discover = self.hspec-discover_2_11_5;
-    hspec-core = self.hspec-core_2_11_5;
+  hspec_2_11_6 = doDistribute (super.hspec_2_11_6.override {
+    hspec-discover = self.hspec-discover_2_11_6;
+    hspec-core = self.hspec-core_2_11_6;
   });
-  hspec-meta_2_11_5 = doDistribute (super.hspec-meta_2_11_5.override {
+  hspec-meta_2_11_6 = doDistribute (super.hspec-meta_2_11_6.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   });
-  hspec-discover_2_11_5 = doDistribute (super.hspec-discover_2_11_5.override {
-    hspec-meta = self.hspec-meta_2_11_5;
+  hspec-discover_2_11_6 = doDistribute (super.hspec-discover_2_11_6.override {
+    hspec-meta = self.hspec-meta_2_11_6;
   });
   # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_5
   # is overlayed to hspec-core.
-  hspec-core_2_11_5 = doDistribute (dontCheck (super.hspec-core_2_11_5.override {
+  hspec-core_2_11_6 = doDistribute (dontCheck (super.hspec-core_2_11_6.override {
     hspec-expectations = self.hspec-expectations_0_8_4;
   }));
@@ -1679,19 +1674,19 @@ self: super: {
   });
-  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_5
+  # Need to disable tests to prevent an infinite recursion if hspec-core_2_11_6
   # is overlayed to hspec-core.